# MetadataSyncPolicy

MetadataSyncPolicy defines policies when syncing metadata
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**auto_sync** | **bool** | AutoSync enables automatic metadata sync when setting up a runtime. If not set, it defaults to true. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


